@@ -1,11 +1,12 @@
 // SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "ImageDate.h"
 
 #include <KLocalizedString>
+#include <QDebug>
 #include <QLocale>
 #include <qregexp.h>
 
@@ -14,16 +15,69 @@ using namespace DB;
 static const QTime _startOfDay_(0, 0, 0);
 static const QTime _endOfDay_(23, 59, 59);
 
+namespace
+{
+
+QStringList monthNames()
+{
+    static QStringList res;
+    if (res.isEmpty()) {
+        for (int i = 1; i <= 12; ++i) {
+            res << QLocale().standaloneMonthName(i, QLocale::ShortFormat);
+        }
+        for (int i = 1; i <= 12; ++i) {
+            res << QLocale().standaloneMonthName(i, QLocale::LongFormat);
+        }
+
+        res << i18nc("Abbreviated month name", "jan") << i18nc("Abbreviated month name", "feb")
+            << i18nc("Abbreviated month name", "mar") << i18nc("Abbreviated month name", "apr")
+            << i18nc("Abbreviated month name", "may") << i18nc("Abbreviated month name", "jun")
+            << i18nc("Abbreviated month name", "jul") << i18nc("Abbreviated month name", "aug")
+            << i18nc("Abbreviated month name", "sep") << i18nc("Abbreviated month name", "oct")
+            << i18nc("Abbreviated month name", "nov") << i18nc("Abbreviated month name", "dec");
+        res << QString::fromLatin1("jan") << QString::fromLatin1("feb") << QString::fromLatin1("mar") << QString::fromLatin1("apr")
+            << QString::fromLatin1("may") << QString::fromLatin1("jun") << QString::fromLatin1("jul") << QString::fromLatin1("aug")
+            << QString::fromLatin1("sep") << QString::fromLatin1("oct") << QString::fromLatin1("nov") << QString::fromLatin1("dec");
+
+        for (int i = 1; i <= 12; ++i) {
+            res << QLocale().monthName(i, QLocale::ShortFormat);
+        }
+        for (int i = 1; i <= 12; ++i) {
+            res << QLocale().monthName(i, QLocale::LongFormat);
+        }
+
+        for (QStringList::iterator it = res.begin(); it != res.end(); ++it)
+            *it = it->toLower();
+    }
+    return res;
+}
+
+QString formatRegexp()
+{
+    static QString str;
+    if (str.isEmpty()) {
+        str = QString::fromLatin1("^((\\d\\d?)([-. /]+|$))?((");
+        QStringList months = monthNames();
+        for (QStringList::ConstIterator monthIt = months.constBegin(); monthIt != months.constEnd(); ++monthIt)
+            str += QString::fromLatin1("%1|").arg(*monthIt);
+
+        str += QString::fromLatin1("\\d?\\d)([-. /]+|$))?(\\d\\d(\\d\\d)?)?$");
+    }
+    return str;
+}
+
+} // namespace
+
 ImageDate::ImageDate(const QDate &date)
+    : m_start(date, _startOfDay_)
+    , m_end(m_start)
 {
-    m_start = Utilities::FastDateTime(date, _startOfDay_);
-    m_end = m_start;
 }
 
 ImageDate::ImageDate(const Utilities::FastDateTime &date)
+    : m_start(date)
+    , m_end(date)
 {
-    m_start = date;
-    m_end = date;
 }
 
 bool ImageDate::operator<=(const ImageDate &other) const
@@ -33,6 +87,8 @@ bool ImageDate::operator<=(const ImageDate &other) const
 }
 
 ImageDate::ImageDate()
+    : m_start()
+    , m_end()
 {
 }
 
@@ -139,20 +195,6 @@ bool ImageDate::operator!=(const ImageDate &other) const
     return !(*this == other);
 }
 
-QString ImageDate::formatRegexp()
-{
-    static QString str;
-    if (str.isEmpty()) {
-        str = QString::fromLatin1("^((\\d\\d?)([-. /]+|$))?((");
-        QStringList months = monthNames();
-        for (QStringList::ConstIterator monthIt = months.constBegin(); monthIt != months.constEnd(); ++monthIt)
-            str += QString::fromLatin1("%1|").arg(*monthIt);
-
-        str += QString::fromLatin1("\\d?\\d)([-. /]+|$))?(\\d\\d(\\d\\d)?)?$");
-    }
-    return str;
-}
-
 bool ImageDate::operator<(const ImageDate &other) const
 {
     return start() < other.start() || (start() == other.start() && end() < other.end());
@@ -236,15 +278,70 @@ ImageDate::ImageDate(int yearFrom, int monthFrom, int dayFrom, int yearTo, int m
     }
 }
 
-QDate ImageDate::parseDate(const QString &date, bool startDate)
+bool ImageDate::hasValidTime() const
 {
-    int year = 0;
-    int month = 0;
-    int day = 0;
+    return m_start == m_end;
+}
 
+ImageDate::ImageDate(const QDate &start, const QDate &end, const QTime &time)
+{
+    const QDate validatedEnd = (end.isValid()) ? end : start;
+
+    if (start == validatedEnd && time.isValid()) {
+        m_start = Utilities::FastDateTime(start, time);
+        m_end = m_start;
+    } else {
+        if (start > validatedEnd) {
+            m_end = Utilities::FastDateTime(start, _startOfDay_);
+            m_start = Utilities::FastDateTime(validatedEnd, _endOfDay_);
+        } else {
+            m_start = Utilities::FastDateTime(start, _startOfDay_);
+            m_end = Utilities::FastDateTime(validatedEnd, _endOfDay_);
+        }
+    }
+}
+
+ImageDate::MatchType ImageDate::isIncludedIn(const ImageDate &searchRange) const
+{
+    if (searchRange.start() <= start() && searchRange.end() >= end())
+        return MatchType::IsContained;
+
+    if (searchRange.start() <= end() && searchRange.end() >= start()) {
+        return MatchType::Overlap;
+    }
+    return MatchType::NoMatch;
+}
+
+bool ImageDate::includes(const Utilities::FastDateTime &date) const
+{
+    return ImageDate(date).isIncludedIn(*this) == MatchType::IsContained;
+}
+
+void ImageDate::extendTo(const ImageDate &other)
+{
+    if (other.isNull())
+        return;
+
+    if (isNull()) {
+        m_start = other.m_start;
+        m_end = other.m_end;
+    } else {
+        if (other.m_start < m_start)
+            m_start = other.m_start;
+        if (other.m_end > m_end)
+            m_end = other.m_end;
+    }
+}
+
+QDate DB::parseDateString(const QString &dateString, bool assumeStartDate)
+{
     QRegExp regexp(formatRegexp(), Qt::CaseInsensitive);
 
-    if (regexp.exactMatch(date)) {
+    if (regexp.exactMatch(dateString)) {
+        int year = 0;
+        int month = 0;
+        int day = 0;
+
         QString dayStr = regexp.cap(2);
         QString monthStr = regexp.cap(5).toLower();
         QString yearStr = regexp.cap(7);
@@ -269,7 +366,7 @@ QDate ImageDate::parseDate(const QString &date, bool startDate)
         if (year == 0)
             year = QDate::currentDate().year();
         if (month == 0) {
-            if (startDate) {
+            if (assumeStartDate) {
                 month = 1;
                 day = 1;
             } else {
@@ -277,7 +374,7 @@ QDate ImageDate::parseDate(const QString &date, bool startDate)
                 day = 31;
             }
         } else if (day == 0) {
-            if (startDate)
+            if (assumeStartDate)
                 day = 1;
             else
                 day = QDate(year, month, 1).daysInMonth();
@@ -287,94 +384,18 @@ QDate ImageDate::parseDate(const QString &date, bool startDate)
         return QDate();
 }
 
-bool ImageDate::hasValidTime() const
+QDebug operator<<(QDebug debug, const DB::ImageDate &d)
 {
-    return m_start == m_end;
-}
+    QDebugStateSaver saveState(debug);
 
-ImageDate::ImageDate(const QDate &start, QDate end, const QTime &time)
-{
-    if (!end.isValid())
-        end = start;
-
-    if (start == end && time.isValid()) {
-        m_start = Utilities::FastDateTime(start, time);
-        m_end = m_start;
+    if (d.isNull()) {
+        debug << "DB::ImageDate()";
+    } else if (d.isFuzzy()) {
+        debug.nospace() << "DB::ImageDate(" << d.start().date().toString(Qt::ISODate) << ", " << d.end().date().toString(Qt::ISODate) << ")";
     } else {
-        if (start > end) {
-            m_end = Utilities::FastDateTime(start, _startOfDay_);
-            m_start = Utilities::FastDateTime(end, _endOfDay_);
-        } else {
-            m_start = Utilities::FastDateTime(start, _startOfDay_);
-            m_end = Utilities::FastDateTime(end, _endOfDay_);
-        }
+        debug.nospace() << "DB::ImageDate(" << d.start().date().toString(Qt::ISODate) << ")";
     }
-}
-
-ImageDate::MatchType ImageDate::isIncludedIn(const ImageDate &searchRange) const
-{
-    if (searchRange.start() <= start() && searchRange.end() >= end())
-        return ExactMatch;
-
-    if (searchRange.start() <= end() && searchRange.end() >= start()) {
-        return RangeMatch;
-    }
-    return DontMatch;
-}
-
-bool ImageDate::includes(const Utilities::FastDateTime &date) const
-{
-    return ImageDate(date).isIncludedIn(*this) == ExactMatch;
-}
-
-void ImageDate::extendTo(const ImageDate &other)
-{
-    if (other.isNull())
-        return;
-
-    if (isNull()) {
-        m_start = other.m_start;
-        m_end = other.m_end;
-    } else {
-        if (other.m_start < m_start)
-            m_start = other.m_start;
-        if (other.m_end > m_end)
-            m_end = other.m_end;
-    }
-}
-
-QStringList DB::ImageDate::monthNames()
-{
-    static QStringList res;
-    if (res.isEmpty()) {
-        for (int i = 1; i <= 12; ++i) {
-            res << QLocale().standaloneMonthName(i, QLocale::ShortFormat);
-        }
-        for (int i = 1; i <= 12; ++i) {
-            res << QLocale().standaloneMonthName(i, QLocale::LongFormat);
-        }
-
-        res << i18nc("Abbreviated month name", "jan") << i18nc("Abbreviated month name", "feb")
-            << i18nc("Abbreviated month name", "mar") << i18nc("Abbreviated month name", "apr")
-            << i18nc("Abbreviated month name", "may") << i18nc("Abbreviated month name", "jun")
-            << i18nc("Abbreviated month name", "jul") << i18nc("Abbreviated month name", "aug")
-            << i18nc("Abbreviated month name", "sep") << i18nc("Abbreviated month name", "oct")
-            << i18nc("Abbreviated month name", "nov") << i18nc("Abbreviated month name", "dec");
-        res << QString::fromLatin1("jan") << QString::fromLatin1("feb") << QString::fromLatin1("mar") << QString::fromLatin1("apr")
-            << QString::fromLatin1("may") << QString::fromLatin1("jun") << QString::fromLatin1("jul") << QString::fromLatin1("aug")
-            << QString::fromLatin1("sep") << QString::fromLatin1("oct") << QString::fromLatin1("nov") << QString::fromLatin1("dec");
-
-        for (int i = 1; i <= 12; ++i) {
-            res << QLocale().monthName(i, QLocale::ShortFormat);
-        }
-        for (int i = 1; i <= 12; ++i) {
-            res << QLocale().monthName(i, QLocale::LongFormat);
-        }
-
-        for (QStringList::iterator it = res.begin(); it != res.end(); ++it)
-            *it = it->toLower();
-    }
-    return res;
+    return debug;
 }
 
 // vi:expandtab:tabstop=4 shiftwidth=4:
