@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -10,6 +10,7 @@
 #include "ImageScout.h"
 #include "MD5Map.h"
 
+#include <BackgroundJobs/HandleVideoThumbnailRequestJob.h>
 #include <BackgroundJobs/ReadVideoLengthJob.h>
 #include <BackgroundJobs/SearchForVideosWithoutVideoThumbnailsJob.h>
 #include <BackgroundTaskManager/JobManager.h>
@@ -18,7 +19,7 @@
 #include <MainWindow/FeatureDialog.h>
 #include <MainWindow/Window.h>
 #include <Utilities/FileUtil.h>
-#include <Utilities/VideoUtil.h>
+#include <kpabase/FileExtensions.h>
 #include <kpabase/FileNameUtil.h>
 #include <kpabase/Logging.h>
 #include <kpabase/SettingsData.h>
@@ -429,7 +430,7 @@ void NewImageFinder::searchForNewFiles(const DB::FileNameSet &loadedFiles, QStri
         const DB::FileName file = DB::FileName::fromAbsolutePath(directory + QString::fromLatin1("/") + *it);
         if ((*it) == QString::fromLatin1(".") || (*it) == QString::fromLatin1("..")
             || excluded.contains((*it)) || loadedFiles.contains(file)
-            || rawDec.fileCanBeSkipped(loadedFiles, file)
+            || KPABase::fileCanBeSkipped(loadedFiles, file)
             || (*it) == QString::fromLatin1("CategoryImages"))
             continue;
 
@@ -445,7 +446,7 @@ void NewImageFinder::searchForNewFiles(const DB::FileNameSet &loadedFiles, QStri
                 if (canReadImage(file)) {
                     qCDebug(DBFileOpsLog) << "Found new image:" << file.relative();
                     m_pendingLoad.append(qMakePair(file, DB::Image));
-                } else if (Utilities::isVideo(file)) {
+                } else if (KPABase::isVideo(file)) {
                     qCDebug(DBFileOpsLog) << "Found new video:" << file.relative();
                     m_pendingLoad.append(qMakePair(file, DB::Video));
                 }
@@ -712,6 +713,7 @@ bool NewImageFinder::calculateMD5sums(
             info->setMD5Sum(md5);
             dirty = true;
             MainWindow::Window::theMainWindow()->thumbnailCache()->removeThumbnail(fileName);
+            BackgroundJobs::HandleVideoThumbnailRequestJob::removeFullScaleFrame(fileName);
         }
 
         md5Map->insert(md5, fileName);
