@@ -1,6 +1,14 @@
-// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-//
+// SPDX-FileCopyrightText: 2003 David Faure <faure@kde.org>
+// SPDX-FileCopyrightText: 2003 Simon Hausmann <hausmann@kde.org>
+// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+// SPDX-FileCopyrightText: 2005-2007 Dirk Mueller <mueller@kde.org>
+// SPDX-FileCopyrightText: 2007 Tuomas Suutari <tuomas@nepnep.net>
+// SPDX-FileCopyrightText: 2008 Henner Zeller <h.zeller@acm.org>
+// SPDX-FileCopyrightText: 2008-2013 Jan Kundrát <jkt@flaska.net>
+// SPDX-FileCopyrightText: 2013 Andreas Neustifter <andreas.neustifter@gmail.com>
+// SPDX-FileCopyrightText: 2013-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2018-2019 Robert Krawitz <rlk@alum.mit.edu>
+
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "AsyncLoader.h"
@@ -14,7 +22,7 @@
 #include <BackgroundJobs/HandleVideoThumbnailRequestJob.h>
 #include <BackgroundTaskManager/JobManager.h>
 #include <MainWindow/FeatureDialog.h>
-#include <Utilities/VideoUtil.h>
+#include <kpabase/FileExtensions.h>
 #include <kpabase/SettingsData.h>
 #include <kpathumbnails/ThumbnailCache.h>
 
@@ -81,7 +89,7 @@ bool ImageManager::AsyncLoader::load(ImageRequest *request)
     // if ( ! request->fileSystemFileName().exists() )
     //    return false;
 
-    if (Utilities::isVideo(request->fileSystemFileName())) {
+    if (KPABase::isVideo(request->fileSystemFileName())) {
         if (!loadVideo(request))
             return false;
     } else {
