@@ -31,10 +31,10 @@
 #include <Browser/BrowserWidget.h>
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
-#include <DB/ImageDateCollection.h>
 #include <DB/ImageInfo.h>
 #include <DB/MD5.h>
 #include <DB/MD5Map.h>
+#include <DB/NewImageFinder.h>
 #include <DateBar/DateBarWidget.h>
 #include <Exif/InfoDialog.h>
 #include <Exif/ReReadDialog.h>
@@ -50,8 +50,8 @@
 #include <Utilities/DemoUtil.h>
 #include <Utilities/List.h>
 #include <Utilities/ShowBusyCursor.h>
-#include <Utilities/VideoUtil.h>
 #include <Viewer/ViewerWidget.h>
+#include <kpabase/FileExtensions.h>
 #include <kpabase/FileNameUtil.h>
 #include <kpabase/Logging.h>
 #include <kpabase/SettingsData.h>
@@ -77,9 +77,16 @@
 #include <stdlib.h>
 #endif
 
+#include <kconfigwidgets_version.h>
+#include <kio_version.h> // for #if KIO_VERSION...
+#include <kwidgetsaddons_version.h>
+
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KColorSchemeManager>
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 107, 0)
+#include <KColorSchemeMenu>
+#endif
 #include <KConfigGroup>
 #include <KEditToolBar>
 #include <KIconLoader>
@@ -115,10 +122,7 @@
 #include <QTimer>
 #include <QVBoxLayout>
 #include <functional>
-#include <kconfigwidgets_version.h>
-#include <kio_version.h> // for #if KIO_VERSION...
 #include <ktip.h>
-#include <kwidgetsaddons_version.h>
 
 using namespace DB;
 
@@ -262,7 +266,7 @@ void MainWindow::Window::delayedInit()
     if (Settings::SettingsData::instance()->searchForImagesOnStart() || Options::the()->searchForImagesOnStart()) {
         splash->message(i18n("Searching for New Files"));
         qApp->processEvents();
-        DB::ImageDB::instance()->slotRescan();
+        DB::NewImageFinder().findImages();
         qCInfo(TimingLog) << "MainWindow: Search for New Files: " << timer.restart() << "ms.";
     }
 
@@ -544,7 +548,7 @@ void MainWindow::Window::slotPasteInformation()
     if (!mimeData->hasUrls() || mimeData->urls().length() != 1)
         return;
 
-    const QUrl url = mimeData->urls().first();
+    const QUrl url = mimeData->urls().constFirst();
     if (!url.isLocalFile())
         return;
 
@@ -937,7 +941,14 @@ void MainWindow::Window::setupMenuBar()
     const QString schemePath = Settings::SettingsData::instance()->colorScheme();
     const auto schemeCfg = KSharedConfig::openConfig(schemePath);
     const QString activeSchemeName = schemeCfg->group("General").readEntry("Name", QFileInfo(schemePath).baseName());
+#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 107, 0)
+    const auto activeSchemeIndex = schemes->indexForScheme(activeSchemeName);
+    if (activeSchemeIndex.isValid())
+        schemes->activateScheme(activeSchemeIndex);
+    m_colorSchemeMenu = KColorSchemeMenu::createMenu(schemes, this);
+#else
     m_colorSchemeMenu = schemes->createSchemeSelectionMenu(activeSchemeName, this);
+#endif
     m_colorSchemeMenu->setText(i18n("Choose Color Scheme"));
     m_colorSchemeMenu->setIcon(QIcon::fromTheme(QString::fromLatin1("color")));
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
@@ -954,17 +965,12 @@ void MainWindow::Window::setupMenuBar()
     a = actionCollection()->addAction(QString::fromLatin1("findImagesWithInvalidDate"), this, &Window::slotShowImagesWithInvalidDate);
     a->setText(i18n("Display Images and Videos with Incomplete Dates..."));
 
-#ifdef DOES_STILL_NOT_WORK_IN_KPA4
-    a = actionCollection()->addAction(QString::fromLatin1("findImagesWithChangedMD5Sum"), this, SLOT(slotShowImagesWithChangedMD5Sum()));
-    a->setText(i18n("Display Images and Videos with Changed MD5 Sum"));
-#endif // DOES_STILL_NOT_WORK_IN_KPA4
-
     a = actionCollection()->addAction(QLatin1String("mergeDuplicates"), this, &Window::mergeDuplicates);
     a->setText(i18n("Merge duplicates"));
     a = actionCollection()->addAction(QString::fromLatin1("rebuildMD5s"), this, &Window::slotRecalcCheckSums);
-    a->setText(i18n("Recalculate Checksum"));
+    a->setText(i18n("Refresh Selected Thumbnails and Checksums"));
 
-    a = actionCollection()->addAction(QString::fromLatin1("rescan"), DB::ImageDB::instance(), &DB::ImageDB::slotRescan);
+    a = actionCollection()->addAction(QString::fromLatin1("rescan"), this, &Window::slotRescan);
     a->setIcon(QIcon::fromTheme(QString::fromLatin1("document-import")));
     a->setText(i18n("Rescan for Images and Videos"));
 
@@ -1018,8 +1024,8 @@ void MainWindow::Window::setupMenuBar()
     m_showExifDialog = actionCollection()->addAction(QString::fromLatin1("showExifInfo"), this, &Window::slotShowExifInfo);
     m_showExifDialog->setText(i18n("Show Exif Info and file metadata"));
 
-    m_recreateThumbnails = actionCollection()->addAction(QString::fromLatin1("recreateThumbnails"), m_thumbnailView, &ThumbnailView::ThumbnailFacade::slotRecreateThumbnail);
-    m_recreateThumbnails->setText(i18n("Recreate Selected Thumbnails"));
+    m_recreateThumbnails = actionCollection()->addAction(QString::fromLatin1("recreateThumbnails"), this, &Window::slotRecalcCheckSums);
+    m_recreateThumbnails->setText(i18n("Refresh Selected Thumbnails and Checksums"));
 
     m_useNextVideoThumbnail = actionCollection()->addAction(QString::fromLatin1("useNextVideoThumbnail"), this, &Window::useNextVideoThumbnail);
     m_useNextVideoThumbnail->setText(i18n("Use next video thumbnail"));
@@ -1135,7 +1141,7 @@ bool MainWindow::Window::load()
         KConfigGroup config = KSharedConfig::openConfig()->group(QString::fromUtf8("General"));
         if (config.hasKey(QString::fromLatin1("imageDBFile"))) {
             configFile = config.readEntry<QString>(QString::fromLatin1("imageDBFile"), QString());
-            if (!QFileInfo(configFile).exists())
+            if (!QFileInfo::exists(configFile))
                 showWelcome = true;
         } else
             showWelcome = true;
@@ -1285,7 +1291,7 @@ void MainWindow::Window::triggerCopyLinkAction(CopyLinkEngine::Action action)
     }
 
     QList<QUrl> selectedFiles;
-    for (const QString &path : selection) {
+    for (const QString &path : qAsConst(selection)) {
         selectedFiles.append(QUrl::fromLocalFile(path));
     }
 
@@ -1509,7 +1515,7 @@ void MainWindow::Window::setupPluginMenu()
     Plugins::PurposeMenu *purposeMenu = new Plugins::PurposeMenu(menu);
     connect(m_thumbnailView, &ThumbnailView::ThumbnailFacade::selectionChanged,
             purposeMenu, &Plugins::PurposeMenu::slotSelectionChanged);
-    connect(purposeMenu, &Plugins::PurposeMenu::imageShared, [this](QUrl shareLocation) {
+    connect(purposeMenu, &Plugins::PurposeMenu::imageShared, this, [this](QUrl shareLocation) {
         QString message;
         if (shareLocation.isValid()) {
             message = i18n("Successfully shared image(s). Copying location to clipboard...");
@@ -1519,7 +1525,7 @@ void MainWindow::Window::setupPluginMenu()
         }
         m_statusBar->showMessage(message);
     });
-    connect(purposeMenu, &Plugins::PurposeMenu::imageSharingFailed, [this](QString errorMessage) {
+    connect(purposeMenu, &Plugins::PurposeMenu::imageSharingFailed, this, [this](QString errorMessage) {
         QString message = i18n("Image sharing failed with message: %1", errorMessage);
         m_statusBar->showMessage(message);
     });
@@ -1612,7 +1618,8 @@ void MainWindow::Window::updateDateBar(const Browser::BreadcrumbList &path)
 
 void MainWindow::Window::updateDateBar()
 {
-    m_dateBar->setImageDateCollection(DB::ImageDB::instance()->rangeCollection());
+    const auto imageList = DB::ImageDB::instance()->search(Browser::BrowserWidget::instance()->currentContext(), DB::SearchOption::AllowRangeMatch);
+    m_dateBar->setImageCollection(imageList);
 }
 
 void MainWindow::Window::slotShowImagesWithInvalidDate()
@@ -1660,7 +1667,21 @@ void MainWindow::Window::showThumbNails(const FileNameList &items)
 
 void MainWindow::Window::slotRecalcCheckSums()
 {
-    DB::ImageDB::instance()->slotRecalcCheckSums(selected());
+    auto images = selected();
+
+    const auto db = DB::ImageDB::instance();
+    if (images.isEmpty()) {
+        images = db->files();
+        // avoid lookups
+        db->md5Map()->clear();
+    }
+
+    DB::NewImageFinder().calculateMD5sums(images, db->md5Map());
+}
+
+void MainWindow::Window::slotRescan()
+{
+    NewImageFinder().findImages();
 }
 
 void MainWindow::Window::slotShowExifInfo()
@@ -1746,7 +1767,7 @@ void MainWindow::Window::setupStatusBar()
     m_statusBar = new MainWindow::StatusBar;
     setStatusBar(m_statusBar);
     setLocked(Settings::SettingsData::instance()->locked(), true, false);
-    connect(m_statusBar, &StatusBar::thumbnailSettingsRequested, [this]() { this->slotOptions(); m_settingsDialog->activatePage(Settings::SettingsPage::ThumbnailsPage); });
+    connect(m_statusBar, &StatusBar::thumbnailSettingsRequested, this, [this]() { this->slotOptions(); m_settingsDialog->activatePage(Settings::SettingsPage::ThumbnailsPage); });
 }
 
 void MainWindow::Window::slotRecreateExifDB()
@@ -1845,7 +1866,7 @@ bool MainWindow::Window::anyVideosSelected() const
 {
     const auto selectedFiles = selected();
     for (const DB::FileName &fileName : selectedFiles) {
-        if (Utilities::isVideo(fileName))
+        if (KPABase::isVideo(fileName))
             return true;
     }
     return false;
