@@ -1,5 +1,5 @@
-// SPDX-FileCopyrightText: 2014-2015 Tobias Leupold <tl at stonemx dot de>
 // SPDX-FileCopyrightText: 2016-2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2014-2022 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -168,7 +168,7 @@ Q_SIGNALS:
     void newRegionSelected(Map::GeoCoordinates::LatLonBox coordinates);
     void displayStatusChanged(MapStatus);
 
-public slots:
+public Q_SLOTS:
     /**
      * Centers the map on the coordinates of the given image.
      */
@@ -177,7 +177,7 @@ public slots:
     void increaseMarkerSize();
     void decreaseMarkerSize();
 
-private slots:
+private Q_SLOTS:
     void saveSettings();
     void setLastCenter();
     void updateRegionSelection(const Marble::GeoDataLatLonBox &selection);
