@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -170,16 +170,6 @@ ThumbnailView::ThumbnailFacade *ThumbnailView::ThumbnailFacade::instance()
     return s_instance;
 }
 
-void ThumbnailView::ThumbnailFacade::slotRecreateThumbnail()
-{
-    const auto selection = widget()->selection(NoExpandCollapsedStacks);
-    for (const DB::FileName &fileName : selection) {
-        m_thumbnailCache->removeThumbnail(fileName);
-        BackgroundJobs::HandleVideoThumbnailRequestJob::removeFullScaleFrame(fileName);
-        m_model->updateCell(fileName);
-    }
-}
-
 void ThumbnailView::ThumbnailFacade::clearFilter()
 {
     Q_ASSERT(m_model);
