@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -249,7 +250,7 @@ public:
     int getThumbnailPreloadThreadCount() const;
     int getThumbnailBuilderThreadCount() const;
 
-signals:
+Q_SIGNALS:
     void locked(bool lock, bool exclude);
     void viewSortTypeChanged(Settings::ViewSortType);
     void matchTypeChanged(AnnotationDialog::MatchType);
@@ -258,6 +259,16 @@ signals:
     void actualThumbnailSizeChanged(int);
     void histogramScaleChanged();
     void colorSchemeChanged();
+    void displayLabelsChanged(bool);
+    void displayCategoriesChanged(bool);
+    /**
+     * @brief untaggedTagChanged is emitted when untaggedCategory() or untaggedTag() changes.
+     * Note that code in KPhotoAlbum currently calls setUntaggedCategory(const QString&) and setUntaggedTag(const QString&),
+     * const QString&), which may result in the signal being triggered two times instead of once.
+     * @param category
+     * @param tag
+     */
+    void untaggedTagChanged(const QString &category, const QString &tag);
 
 private:
     SettingsData(const QString &imageDirectory, DB::UIDelegate &delegate);
